==> openshift-model-6.8.0-sources.jar: io/fabric8/openshift/api/model/ImageLookupPolicyFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ImageLookupPolicyFluent<A extends ImageLookupPolicyFluent<A>> extends BaseFluent<A>{
  public ImageLookupPolicyFluent() {
  }
  public ImageLookupPolicyFluent(ImageLookupPolicy instance) {
    instance = (instance != null ? instance : new ImageLookupPolicy());

    if (instance != null) {
      this.withLocal(instance.getLocal());
      this.withLocal(instance.getLocal());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Boolean local;
  private Map<String,Object> additionalProperties;
  public Boolean getLocal() {
    return this.local;
  }
  public A withLocal(Boolean local) {
    this.local=local; return (A) this;
  }
  public boolean hasLocal() {
    return this.local != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageLookupPolicyFluent that = (ImageLookupPolicyFluent) o;
    if (!java.util.Objects.equals(local, that.local)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(local,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (local != null) { sb.append("local:"); sb.append(local + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public A withLocal() {
    return withLocal(true);
  }
  
}

==> openshift-model-6.9.0-sources.jar: io/fabric8/openshift/api/model/ImageLookupPolicyFluent.java <==
package io.fabric8.openshift.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ImageLookupPolicyFluent<A extends ImageLookupPolicyFluent<A>> extends BaseFluent<A>{
  public ImageLookupPolicyFluent() {
  }
  
  public ImageLookupPolicyFluent(ImageLookupPolicy instance) {
    this.copyInstance(instance);
  }
  private Boolean local;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(ImageLookupPolicy instance) {
    instance = (instance != null ? instance : new ImageLookupPolicy());
  
    if (instance != null) {
        this.withLocal(instance.getLocal());
        this.withLocal(instance.getLocal());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public Boolean getLocal() {
    return this.local;
  }
  
  public A withLocal(Boolean local) {
    this.local=local; return (A) this;
  }
  
  public boolean hasLocal() {
    return this.local != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageLookupPolicyFluent that = (ImageLookupPolicyFluent) o;
    if (!java.util.Objects.equals(local, that.local)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(local,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (local != null) { sb.append("local:"); sb.append(local + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withLocal() {
    return withLocal(true);
  }
  

}
